# Terramagic CLI


## Motivation

Every time , I needed create a terraform files to a new project, and a new terraform files., but this is not good. and now we have a Terramagic tool to help us to create a terraform files.

## Requirements

- Python 3.9 >=

## How to install?

```shell
pip install terramagic
```

## Hands on

## Check the version


## Usage(Ex.)

```shell
terramagic create-project --name <project_name> --env <env>
```

```shell
terramagic create-project --name terraform --env prod --env dev
```

## How to use this tool ?

```shell
Usage: terramagic create-project [OPTIONS]


Options:
  -n, --name TEXT  Name of the project
  -e, --env TEXT   Environment name(dev, test, prd)
  --help           Show this message and exit.
```

Enjoy!
